#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gitit
version:              0.16
visibility:           public
id:                   gitit-0.16-OUgfy2tPH7B66SUF3FBMH
key:                  gitit-0.16-OUgfy2tPH7B66SUF3FBMH
license:              LicenseRef-GPL
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
stability:            experimental
synopsis:             Wiki using happstack, git or darcs, and pandoc.
description:
    Gitit is a wiki backed by a git, darcs, or mercurial
    filestore.  Pages and uploaded files can be modified either
    directly via the VCS'\''s command-line tools or through
    the wiki'\''s web interface. Pandoc is used for markup
    processing, so pages may be written in
    (extended) markdown, reStructuredText, LaTeX, HTML,
    or literate Haskell.

    Notable features include

    * plugins: dynamically loaded page
    transformations written in Haskell (see
    "Network.Gitit.Interface")

    * conversion of TeX math to MathML for display in
    web browsers

    * syntax highlighting of source code
    files and code snippets

    * Atom feeds (site-wide and per-page)

    * a library, "Network.Gitit", that makes it simple
    to include a gitit wiki in any happstack application

    For usage information:  @gitit --help@

category:             Network
abi:                  2213d34fa5ea5cd30c90053b83bccd89
exposed:              True
exposed-modules:
    Network.Gitit Network.Gitit.Authentication
    Network.Gitit.Authentication.Github Network.Gitit.Cache
    Network.Gitit.Compat.Except Network.Gitit.Config
    Network.Gitit.ContentTransformer Network.Gitit.Feed
    Network.Gitit.Framework Network.Gitit.Handlers
    Network.Gitit.Initialize Network.Gitit.Interface
    Network.Gitit.Layout Network.Gitit.Page Network.Gitit.Plugins
    Network.Gitit.Server Network.Gitit.State Network.Gitit.Types
    Network.Gitit.Util Paths_gitit

import-dirs:          /usr/lib/ghc-9.6.6/site-local/gitit-0.16
library-dirs:         /usr/lib/ghc-9.6.6/site-local/gitit-0.16
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/gitit-0.16
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/gitit
hs-libraries:         HSgitit-0.16-OUgfy2tPH7B66SUF3FBMH
depends:
    HStringTemplate-0.8.8-FEd3t5UEdsq4XH5qg0fXvh
    HTTP-4000.5.0-AUFz4SV7IsmFU722g0miEw
    SHA-1.6.4.4-KRZJCS52poaHfqPlW5b8Sg
    aeson-2.2.2.0-p30NU7EGMRKoAj5LcAXNN base-4.18.2.1
    base64-bytestring-1.2.1.0-C0qMqvh3vbu1LTlZEUtx0r
    blaze-html-0.9.2.0-IQpYWAMPsDd8u1EAzkbal7 bytestring-0.11.5.3
    containers-0.6.7 directory-1.3.8.5
    doctemplates-0.11.0.1-INYrVaMqYXHznwSexp6hc
    feed-1.3.2.1-BTvEOw6WuUqEzGw20BA3cl filepath-1.4.300.1
    filestore-0.6.5.1-5PS4dfh8ZMz2lT1zFC0c8r ghc-9.6.6
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    happstack-server-7.9.3-BsI5K0It2xdSVnmvfoCB8
    hoauth2-2.14.0-Lngc6mSP80f5NdI3k48Wl2
    hslogger-1.3.2.0-Kv8fCBI2PkQF3wi9Tfkxar
    http-client-tls-0.3.6.4-2mFFKjIM8FK6v9pBPz2NDG
    http-conduit-2.3.9.1-3jm8Xefkk0i48NyMPf2JnI
    json-0.11-E8FZQs4gKKs2RszbK18Cji mtl-2.3.1
    network-3.1.4.0-946StwFfSrELqUahTPYWqr
    network-bsd-2.8.1.0-3Xg1695908dJSjAmauimMX
    network-uri-2.6.4.2-HyBVnFdXLs0Dgiq4qkHmFH
    old-locale-1.0.0.7-Gunit3UBy5P9OGDVFY5MhC
    old-time-1.1.1.0-CvAEie2oy7M42TGhXKiP0b
    pandoc-3.6.1-F7peNFGbigo1UIAggdl1Pr
    pandoc-types-1.23.1.1-KNM8u0wir7d1sJ8wTKLYRL parsec-3.1.16.1
    pretty-1.1.3.6 process-1.6.19.0
    random-1.2.1.3-L4ByjUo9HMh9NaA0HunG5L
    recaptcha-0.1.0.4-5EcaAWkaNnIKr0AodfwMJl
    safe-0.3.21-CNekTOvlOCxBWhpb53aZQe
    skylighting-0.14.5-vMZYG8PzHL9sozZiGKqQd
    split-0.2.5-3KQHz3VjCt4O3lCLzOFzl syb-0.7.4-6oouIIO3k8DpxFQgfxTIJ
    tagsoup-0.14.8-BmBdL3Esmw8Ks8pI1RIqPE
    temporary-1.3-6jR9Y0qK20e3lOLKCzgpYi text-2.0.2 time-1.12.2
    uri-bytestring-0.3.3.1-73PYNPmMVto8YKcUxHwNVC
    url-2.1.3-FnoMg0Amz5x5iDNEWuwHDq
    utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv
    uuid-1.3.16.1-JVmLTsI5TbjGEwOHOC97Bp xhtml-3000.2.2.1
    xml-1.3.14-3CsuYrgQlhu1X5fBOwcswt
    xml-conduit-1.9.1.4-G1f8ph4UiTy8fbgaTyNDq
    xml-types-0.3.8-ISf6rjkeTjSFXsXdIGBwau
    xss-sanitize-0.3.7.2-LBpnghymvsaFrVEz6472sS
    zlib-0.7.1.0-JUvXnJeECOb5UrlPGbJucV

haddock-interfaces:   /usr/share/doc/gitit/html/gitit.haddock
haddock-html:         /usr/share/doc/gitit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

